@@ -8,7 +8,7 @@ import os
 import re
 import shutil
 
-from servicecatalog_puppet import core, config
+from servicecatalog_puppet import core, config, constants
 
 
 @click.group()
@@ -205,7 +205,6 @@ def bootstrap_spokes_in_ou(
 
 
 @cli.command()
-@click.argument("branch-to-bootstrap")
 @click.option("--with-manual-approvals/--with-no-manual-approvals", default=False)
 @click.option(
     "--puppet-code-pipeline-role-permission-boundary",
@@ -264,180 +263,7 @@ def bootstrap_spokes_in_ou(
 @click.option("--owner")
 @click.option("--repo")
 @click.option("--branch")
-@click.option("--poll-for-source-changes", default=True)
-@click.option("--webhook-secret")
-@click.option("--puppet-role-name", default="PuppetRole", envvar="PUPPET_ROLE_NAME")
-@click.option(
-    "--puppet-role-path", default="/servicecatalog-puppet/", envvar="PUPPET_ROLE_PATH"
-)
-@click.option("--scm-connection-arn", envvar="SCM_CONNECTION_ARN")
-@click.option(
-    "--scm-full-repository-id",
-    default="ServiceCatalogFactory",
-    envvar="SCM_FULL_REPOSITORY_ID",
-)
-@click.option("--scm-branch-name", default="main", envvar="SCM_BRANCH_NAME")
-@click.option("--scm-bucket-name", envvar="SCM_BUCKET_NAME")
-@click.option(
-    "--scm-object-key", default="ServiceCatalogPuppet.zip", envvar="SCM_OBJECT_KEY"
-)
-@click.option(
-    "--create-repo/--no-create-repo", default=False, envvar="SCM_SHOULD_CREATE_REPO"
-)
-def bootstrap_branch(
-    branch_to_bootstrap,
-    with_manual_approvals,
-    puppet_code_pipeline_role_permission_boundary,
-    source_role_permissions_boundary,
-    puppet_generate_role_permission_boundary,
-    puppet_deploy_role_permission_boundary,
-    puppet_provisioning_role_permissions_boundary,
-    cloud_formation_deploy_role_permissions_boundary,
-    deploy_environment_compute_type,
-    deploy_num_workers,
-    source_provider,
-    repository_name,
-    branch_name,
-    owner,
-    repo,
-    branch,
-    poll_for_source_changes,
-    webhook_secret,
-    puppet_role_name,
-    puppet_role_path,
-    scm_connection_arn,
-    scm_full_repository_id,
-    scm_branch_name,
-    scm_bucket_name,
-    scm_object_key,
-    create_repo,
-):
-    puppet_account_id = config.get_puppet_account_id()
-
-    parameters = dict(
-        branch_to_bootstrap=branch_to_bootstrap,
-        with_manual_approvals=with_manual_approvals,
-        puppet_account_id=puppet_account_id,
-        puppet_code_pipeline_role_permission_boundary=puppet_code_pipeline_role_permission_boundary,
-        source_role_permissions_boundary=source_role_permissions_boundary,
-        puppet_generate_role_permission_boundary=puppet_generate_role_permission_boundary,
-        puppet_deploy_role_permission_boundary=puppet_deploy_role_permission_boundary,
-        puppet_provisioning_role_permissions_boundary=puppet_provisioning_role_permissions_boundary,
-        cloud_formation_deploy_role_permissions_boundary=cloud_formation_deploy_role_permissions_boundary,
-        deploy_environment_compute_type=deploy_environment_compute_type,
-        deploy_num_workers=deploy_num_workers,
-        source_provider=source_provider,
-        owner=None,
-        repo=None,
-        branch=None,
-        poll_for_source_changes=None,
-        webhook_secret=None,
-        puppet_role_name=puppet_role_name,
-        puppet_role_path=puppet_role_path,
-        scm_connection_arn=None,
-        scm_full_repository_id=None,
-        scm_branch_name=None,
-        scm_bucket_name=None,
-        scm_object_key=None,
-        scm_skip_creation_of_repo=not create_repo,
-    )
-
-    if source_provider == "CodeCommit":
-        parameters.update(
-            dict(
-                repo=repository_name,
-                branch=branch_name,
-                poll_for_source_changes=poll_for_source_changes,
-            )
-        )
-    elif source_provider == "GitHub":
-        parameters.update(
-            dict(
-                owner=owner,
-                repo=repo,
-                branch=branch,
-                poll_for_source_changes=poll_for_source_changes,
-                webhook_secret=webhook_secret,
-            )
-        )
-    elif source_provider == "CodeStarSourceConnection":
-        parameters.update(
-            dict(
-                scm_connection_arn=scm_connection_arn,
-                scm_full_repository_id=scm_full_repository_id,
-                scm_branch_name=scm_branch_name,
-            )
-        )
-    elif source_provider == "S3":
-        parameters.update(
-            dict(scm_bucket_name=scm_bucket_name, scm_object_key=scm_object_key,)
-        )
-    else:
-        raise Exception(f"Unsupported source provider: {source_provider}")
-
-    core.bootstrap_branch(**parameters)
-
-
-@cli.command()
-@click.option("--with-manual-approvals/--with-no-manual-approvals", default=False)
-@click.option(
-    "--puppet-code-pipeline-role-permission-boundary",
-    default="arn:aws:iam::aws:policy/AdministratorAccess",
-    show_default=True,
-    envvar="PUPPET_CODE_PIPELINE_ROLE_PERMISSION_BOUNDARY",
-)
-@click.option(
-    "--source-role-permissions-boundary",
-    default="arn:aws:iam::aws:policy/AdministratorAccess",
-    show_default=True,
-    envvar="SOURCE_ROLE_PERMISSIONS_BOUNDARY",
-)
-@click.option(
-    "--puppet-generate-role-permission-boundary",
-    default="arn:aws:iam::aws:policy/AdministratorAccess",
-    show_default=True,
-    envvar="PUPPET_GENERATE_ROLE_PERMISSION_BOUNDARY",
-)
-@click.option(
-    "--puppet-deploy-role-permission-boundary",
-    default="arn:aws:iam::aws:policy/AdministratorAccess",
-    show_default=True,
-    envvar="PUPPET_DEPLOY_ROLE_PERMISSION_BOUNDARY",
-)
-@click.option(
-    "--puppet-provisioning-role-permissions-boundary",
-    default="arn:aws:iam::aws:policy/AdministratorAccess",
-    show_default=True,
-    envvar="PUPPET_PROVISIONING_ROLE_PERMISSIONS_BOUNDARY",
-)
-@click.option(
-    "--cloud-formation-deploy-role-permissions-boundary",
-    default="arn:aws:iam::aws:policy/AdministratorAccess",
-    show_default=True,
-    envvar="CLOUD_FORMATION_DEPLOY_ROLE_PERMISSIONS_BOUNDARY",
-)
-@click.option(
-    "--deploy_environment_compute_type",
-    default="BUILD_GENERAL1_SMALL",
-    show_default=True,
-    envvar="DEPLOY_ENVIRONMENT_COMPUTE_TYPE",
-)
-@click.option(
-    "--deploy_num_workers",
-    default=10,
-    type=click.INT,
-    show_default=True,
-    envvar="DEPLOY_NUM_WORKERS",
-)
-@click.option("--source-provider", default="CodeCommit", envvar="SCM_SOURCE_PROVIDER")
-@click.option(
-    "--repository_name", default="ServiceCatalogPuppet", envvar="SCM_REPOSITORY_NAME"
-)
-@click.option("--branch-name", default="master", envvar="SCM_BRANCH_NAME")
-@click.option("--owner")
-@click.option("--repo")
-@click.option("--branch")
-@click.option("--poll-for-source-changes", default=True)
+@click.option("--poll-for-source-changes/--no-poll-for-source-changes", default=True)
 @click.option("--webhook-secret")
 @click.option("--puppet-role-name", default="PuppetRole", envvar="PUPPET_ROLE_NAME")
 @click.option(
@@ -512,24 +338,11 @@ def bootstrap(
         scm_object_key=None,
         scm_skip_creation_of_repo=not create_repo,
     )
-
     if source_provider == "CodeCommit":
-        parameters.update(
-            dict(
-                repo=repository_name,
-                branch=branch_name,
-                poll_for_source_changes=poll_for_source_changes,
-            )
-        )
+        parameters.update(dict(repo=repository_name, branch=branch_name,))
     elif source_provider == "GitHub":
         parameters.update(
-            dict(
-                owner=owner,
-                repo=repo,
-                branch=branch,
-                poll_for_source_changes=poll_for_source_changes,
-                webhook_secret=webhook_secret,
-            )
+            dict(owner=owner, repo=repo, branch=branch, webhook_secret=webhook_secret,)
         )
     elif source_provider == "CodeStarSourceConnection":
         parameters.update(
