@@ -437,15 +437,14 @@ def get_template(
     ]
 
     if is_codecommit:
-        if not scm_skip_creation_of_repo:
-            template.add_resource(
-                codecommit.Repository(
-                    "CodeRepo",
-                    RepositoryName=source.get("Configuration").get("RepositoryName"),
-                    RepositoryDescription="Repo to store the servicecatalog puppet solution",
-                    DeletionPolicy="Retain",
-                )
+        template.add_resource(
+            codecommit.Repository(
+                "CodeRepo",
+                RepositoryName=source.get("Configuration").get("RepositoryName"),
+                RepositoryDescription="Repo to store the servicecatalog puppet solution",
+                DeletionPolicy="Retain",
             )
+        )
 
         source_stage.Actions.append(
             codepipeline.Actions(
@@ -864,7 +863,7 @@ def get_template(
     deploy_project_build_spec["phases"]["build"]["commands"] = [
         "servicecatalog-puppet --info dry-run manifest-expanded.yaml"
     ]
-    deploy_project_build_spec["artifacts"]["name"] = ["DryRunProject"]
+    deploy_project_build_spec["artifacts"]["name"] = "DryRunProject"
     deploy_project_args["Name"] = "servicecatalog-puppet-dryrun"
     deploy_project_args["Description"] = "dry run of servicecatalog-puppet-dryrun"
     deploy_project_args["Source"] = codebuild.Source(
